@@ -3,16 +3,17 @@ OC.L10N.register(
     {
     "Rename" : "Rename",
     "Move" : "Move",
-    "Delete" : "Delete",
     "Search" : "Search",
     "Cancel" : "Cancel",
+    "Shared with you" : "Shared with you",
+    "Files" : "Файлы",
+    "Delete" : "Delete",
     "Title" : "Title",
     "Link" : "Link",
     "Notes" : "Notes",
     "Owner" : "Owner",
     "Share link" : "Share link",
     "Allow editing" : "Дазволіць рэдагаванне",
-    "Select" : "Select",
     "Folder" : "Folder",
     "Save" : "Save"
 },
