@@ -163,7 +163,7 @@ OC.L10N.register(
     "Created {time} ago" : "Vytvorené  {time} spätne",
     "Created on {date}" : "Vytvorené {date}",
     "Owner" : "Majiteľ",
-    "Sharing" : "Sprístupnenie",
+    "Sharing" : "Zdieľanie",
     "Select a user or group" : "Vyberte používateľa alebo skupinu",
     "Share link" : "Sprístupniť odkaz",
     "Reading allowed" : "Čítanie povolené",
@@ -173,7 +173,7 @@ OC.L10N.register(
     "Resharing allowed" : "Opätovné zdieľanie je povolené",
     "Editing allowed" : "Úpravy povolené",
     "Allow editing" : "Povoliť úpravy",
-    "Allow resharing" : "Povoliť sprístupňovanie ďalej",
+    "Allow resharing" : "Povoliť zdieľanie ďalej",
     "Remove share" : "Odstrániť zdieľanie",
     "Link copied" : "Odkaz bol skopírovaný",
     "Privacy" : "Súkromie",
